@@ -3,7 +3,7 @@ package JavaScript::Minifier;
 use strict;
 use warnings;
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.13'; # VERSION
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -357,7 +357,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Crockford ECMAScript JSMin stripDebug
+=for stopwords Crockford ECMAScript JSMin stripDebug Minifying minification minifying minified minify
 
 =head1 NAME
 
@@ -368,11 +368,14 @@ JavaScript::Minifier - Perl extension for minifying JavaScript code
 To minify a JavaScript file and have the output written directly to another file
 
   use JavaScript::Minifier qw(minify);
-  open(INFILE, 'myScript.js') or die;
-  open(OUTFILE, '>myScript-min.js') or die;
-  minify(input => *INFILE, outfile => *OUTFILE);
-  close(INFILE);
-  close(OUTFILE);
+
+  open(my $in, 'myScript.js') or die;
+  open(my $out, '>', 'myScript-min.js') or die;
+
+  minify(input => $in, outfile => $out);
+
+  close($in);
+  close($out);
 
 To minify a JavaScript string literal. Note that by omitting the outfile parameter a the minified code is returned as a string.
 
@@ -425,7 +428,8 @@ Eric Herrera, E<lt>herrera@10east.comE<gt>
 
 =head1 CONTRIBUTORS
 
-Miller 'tmhall' Hall (bug fixes)
+Miller 'tmhall' Hall
+Вячеслав 'vti' Тихановский
 
 =head1 COPYRIGHT AND LICENSE
 
